==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/logout/feature/logout.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { Logout } from './logout.component';
import { MatProgressSpinner } from '@angular/material/progress-spinner';
import { MockComponent } from 'ng-mocks';
import { PageContent } from '../../../ui/common/page-content/page-content.component';

describe('Login', () => {
    let component: Logout;
    let fixture: ComponentFixture<Logout>;

    beforeEach(() => {
        TestBed.configureTestingModule({
            declarations: [Logout],
            imports: [MatProgressSpinner, MockComponent(PageContent)]
        });
        fixture = TestBed.createComponent(Logout);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});

==> nifi-2.7.2-source-release.zip: nifi-2.7.2/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/logout/feature/logout.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { Logout } from './logout.component';
import { MatProgressSpinner } from '@angular/material/progress-spinner';
import { MockComponent } from 'ng-mocks';
import { PageContent } from '../../../ui/common/page-content/page-content.component';

describe('Login', () => {
    let component: Logout;
    let fixture: ComponentFixture<Logout>;

    beforeEach(() => {
        TestBed.configureTestingModule({
            imports: [Logout, MatProgressSpinner, MockComponent(PageContent)]
        });
        fixture = TestBed.createComponent(Logout);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});
